Command line interface (cli package)
====================================

Argument parsing
----------------------------

.. automodule:: gadma.cli.arg_parser
   :members:
   :undoc-members:
   :show-inheritance:

SettingsStorage
----------------------------------

.. automodule:: gadma.cli.settings_storage
   :members:
   :undoc-members:
   :show-inheritance: